# require "elong/api/static/hotel"
require 'open-uri'
require 'active_support/core_ext/hash'
require 'nokogiri'
module Elong
  module API
    module Static
    end
  end
end

module Elong
  module API
    module Static
      class Hotel
        # Elong Hotel Static API Class
        class << self

          # List all hotel 8-bit ids
          #
          # @return [Array]
          def list(status = nil)
            raise "status must be 0 or 1 or nil" unless [0,1,nil].include?status
            noko = Nokogiri::XML(open('http://api.elong.com/xml/v2.0/hotel/hotellist.xml'))
            results = noko.xpath("/HotelIndex/Hotels/Hotel")
            if status
              results.map{|node|node["HotelId"] if node['Status'] == status.to_s}.delete_if{|node|node.nil?}
            else
              results.map{|node|node["HotelId"]}
            end
          end

          # List All Geo Data
          #
          # @return [Hash]
          def geo
            xml = open "http://api.elong.com/xml/v2.0/hotel/geo_cn.xml"
            Hash.from_xml(xml)['HotelGeos']['HotelGeoList']['HotelGeo']
          end

          # Get the detail info of one hotel
          #
          # @return [Hash]
          def detail(hotel_id)
            raise "hotel_id should be String" unless hotel_id.class == String
            begin
              xml = open "http://api.elong.com/xml/v2.0/hotel/cn/#{hotel_id[-2,2]}/#{hotel_id}.xml"
            rescue OpenURI::HTTPError
              return false
            end
            Hash.from_xml(xml)['Hotel']['Detail']
          end

          # Get the brands of hotel
          #
          # @return [Hash]
          def brands
            xml = open "http://api.elong.com/xml/v2.0/hotel/brand_cn.xml"
            Hash.from_xml(xml)['ArrayOfHotelBrand']['HotelBrand']
          end
        end
      end
    end
  end
end